==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ScaleLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ScaleLegendDescription } from "./ScaleLegendDescription";
/**
 * @hidden
 */
var ScaleLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScaleLegendDescriptionMetadata, _super);
    function ScaleLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScaleLegendDescriptionMetadata.b = function (a) {
        if (ScaleLegendDescriptionMetadata.a == null) {
            ScaleLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScaleLegendDescriptionMetadata.c(ScaleLegendDescriptionMetadata.a);
        }
        if (a.g(ScaleLegendDescriptionMetadata.a)) {
            return;
        }
        a.s(ScaleLegendDescriptionMetadata.a);
    };
    ScaleLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
    };
    ScaleLegendDescriptionMetadata.d = function (a) {
        ScaleLegendDescriptionMetadata.b(a);
        a.u("ScaleLegend", function () { return new ScaleLegendDescription(); });
        a.t("ScaleLegend", ScaleLegendDescriptionMetadata.a);
    };
    ScaleLegendDescriptionMetadata.$t = markType(ScaleLegendDescriptionMetadata, 'ScaleLegendDescriptionMetadata');
    ScaleLegendDescriptionMetadata.a = null;
    return ScaleLegendDescriptionMetadata;
}(Base));
export { ScaleLegendDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScaleLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ScaleLegendDescription } from "./ScaleLegendDescription";
/**
 * @hidden
 */
var ScaleLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScaleLegendDescriptionMetadata, _super);
    function ScaleLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScaleLegendDescriptionMetadata.b = function (a) {
        if (ScaleLegendDescriptionMetadata.a == null) {
            ScaleLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScaleLegendDescriptionMetadata.c(ScaleLegendDescriptionMetadata.a);
        }
        if (a.j(ScaleLegendDescriptionMetadata.a)) {
            return;
        }
        a.y(ScaleLegendDescriptionMetadata.a);
    };
    ScaleLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
    };
    ScaleLegendDescriptionMetadata.d = function (a) {
        ScaleLegendDescriptionMetadata.b(a);
        a.aa("ScaleLegend", function () { return new ScaleLegendDescription(); });
        a.z("ScaleLegend", ScaleLegendDescriptionMetadata.a);
    };
    ScaleLegendDescriptionMetadata.$t = markType(ScaleLegendDescriptionMetadata, 'ScaleLegendDescriptionMetadata');
    ScaleLegendDescriptionMetadata.a = null;
    return ScaleLegendDescriptionMetadata;
}(Base));
export { ScaleLegendDescriptionMetadata };
